@@ -25,7 +25,10 @@ pub use decoding::EventsDecodingError;
 pub use event_subscription::{
     subscribe,
     subscribe_finalized,
+    subscribe_to_block_headers_filling_in_gaps,
+    EventSub,
     EventSubscription,
+    FinalizedEventSub,
 };
 pub use events_type::{
     at,
