@@ -81,6 +81,8 @@ pub use crate::{
         Error,
         GenericError,
         HasModuleError,
+        ModuleError,
+        ModuleErrorData,
         RuntimeError,
         TransactionError,
     },
@@ -90,12 +92,11 @@ pub use crate::{
         RawEventDetails,
     },
     extrinsic::{
-        DefaultExtra,
-        DefaultExtraWithTxPayment,
         PairSigner,
-        SignedExtra,
-        Signer,
-        UncheckedExtrinsic,
+        PolkadotExtrinsicParams,
+        PolkadotExtrinsicParamsBuilder,
+        SubstrateExtrinsicParams,
+        SubstrateExtrinsicParamsBuilder,
     },
     metadata::{
         ErrorMetadata,
